--[[ 
Title: Auto Loot
Notes: Enables autolooting when a fishing pole is equipped and disables it afterwards.
Author: Naranja
Version: 1.0
]]

local AceAddon = LibStub("AceAddon-3.0")
AutoLoot = AceAddon:NewAddon("AutoLoot", "AceConsole-3.0", "AceEvent-3.0")
g_MainHandEquip = ""
g_FishingPoleEquipped = false
g_IsEnabled = false

function AutoLoot:OnInitialize()
	self:RegisterEvent("UNIT_INVENTORY_CHANGED")
	self:RegisterChatCommand("autoloot", "handleSlashCommand")
end

function AutoLoot:OnEnable()
	self:handleSlashCommand("enable")
	self:UNIT_INVENTORY_CHANGED("", "player")
end

function AutoLoot:OnDisable()
	
end

function AutoLoot:UNIT_INVENTORY_CHANGED(event, entity)
	if (g_IsEnabled == false) then return end
	
	if (entity == "player") then
		-- Get the main hand item
		local item = GetInventoryItemLink("player", 16)
		if (item == nil) then return end
		
		-- Get the item info
		local 	itemName, 
				itemLink, 
				itemRarity, 
				itemLevel, 
				itemMinLevel, 
				itemType, 
				itemSubType, 
				itemCount, 
				itemEquipLoc, 
				itemTexture = GetItemInfo(item)
		
		-- We only care about main hand item changes
		if (g_MainHandEquip == itemName) then return end
		
		-- If the new item is a fishing pole and currently no fishing pole is equipped
		if (itemType == "Weapon" and itemSubType == "Fishing Poles" and g_FishingPoleEquipped == false) then
			SetCVar("autoLootDefault", "1")
			self:Print("Auto looting: On")
			g_FishingPoleEquipped = true
		-- If we have a fishing pole equipped
		elseif (g_FishingPoleEquipped == true or g_MainHandEquip == "") then
			SetCVar("autoLootDefault", "0")
			self:Print("Auto looting: Off")	
			g_FishingPoleEquipped = false
		end
		
		g_MainHandEquip = itemName
	end
end

function AutoLoot:handleSlashCommand(input)
	if (input == "enable" and not g_IsEnabled) then
		g_IsEnabled = true
		self:Print("Addon Enabled (/autoloot)")
		self:UNIT_INVENTORY_CHANGED("", "player")
	elseif (input == "disable" and g_IsEnabled) then
		g_IsEnabled = false		
		g_MainHandEquip = ""
		g_FishingPoleEquipped = false
		SetCVar("autoLootDefault", "0")
		self:Print("Auto looting: Off")	
		self:Print("Addon Disabled")
	else
		self:Print("Usage: /autoloot [enable | disable]")
	end
	
end